// Copyright 2000 Macromedia, Inc. All rights reserved.


//*-------------------------------------------------------------------
// CLASS:
//   RecordsetMenu
//
// DESCRIPTION:
//
// PUBLIC PROPERTIES:
//
// PUBLIC FUNCTIONS:
//
//--------------------------------------------------------------------




//*-------------------------------------------------------------------
// FUNCTION:
//   RecordsetMenu
//
// DESCRIPTION:
//   Constructor function for the RecordetMenu control
//
// ARGUMENTS:
//   behaviorName - the name of the behavior using this control
//   paramName - the name of the parameter that is being set
//
// RETURNS:
//--------------------------------------------------------------------
function RecordsetMenu(behaviorName, paramName) {
  this.behaviorName = behaviorName;
  this.paramName = paramName;
  
  this.listControl = '';
  
  this.isRecordsetMenu = true;
}

//public methods
RecordsetMenu.prototype.initializeUI = RecordsetMenu_initializeUI;
RecordsetMenu.prototype.findServerBehaviors = RecordsetMenu_findServerBehaviors;
RecordsetMenu.prototype.canApplyServerBehavior = RecordsetMenu_canApplyServerBehavior;
RecordsetMenu.prototype.applyServerBehavior = RecordsetMenu_applyServerBehavior;
RecordsetMenu.prototype.inspectServerBehavior = RecordsetMenu_inspectServerBehavior;
RecordsetMenu.prototype.deleteServerBehavior = RecordsetMenu_deleteServerBehavior;
RecordsetMenu.prototype.analyzeServerBehavior = RecordsetMenu_analyzeServerBehavior;
RecordsetMenu.prototype.getValue = RecordsetMenu_getValue;

//private methods
RecordsetMenu.prototype.findAllRecordsetNames = RecordsetMenu_findAllRecordsetNames;
RecordsetMenu.prototype.rsNameIsValid = RecordsetMenu_rsNameIsValid;


//*-------------------------------------------------------------------
// FUNCTION:
//   initializeUI()
//
// DESCRIPTION:
//   initializes the list control with the names of the recordsets
//
// ARGUMENTS:
//   elementName - (optional) the name of the form control, if it
//                 differs from the parameter name
//
// RETURNS:
//   nothing
//--------------------------------------------------------------------
function RecordsetMenu_initializeUI(elementName) { 
  MM.findAllRecordsetNames = null;  //clear the cache (set later)
  var elemName = (elementName != null) ? elementName : this.paramName;
  
  var nameValueArray = this.findAllRecordsetNames();
  var rsNames = nameValueArray[0];
  var rsValues = nameValueArray[1];
  
  this.listControl = new ListControl(elemName);
  this.listControl.setAll(rsNames,rsValues);
}


//*-------------------------------------------------------------------
// FUNCTION:
//   findServerBehaviors
//
// DESCRIPTION:
//
// ARGUMENTS: 
//
// RETURNS:
//--------------------------------------------------------------------
function RecordsetMenu_findServerBehaviors(paramObj) {
  MM.findAllRecordsetNames = null;  //clear the cache (set later)
}



//*-------------------------------------------------------------------
// FUNCTION:
//   canApplyServerBehavior
//
// DESCRIPTION:
//
// ARGUMENTS: 
//
// RETURNS:
//--------------------------------------------------------------------
function RecordsetMenu_canApplyServerBehavior(sbObj) {
  var retVal = true;
  
  var nameValueArray = this.findAllRecordsetNames();

  var rsNames = nameValueArray[0];

  if (!sbObj && rsNames.length == 0) {  //if there are no Recordsets
    alert(MM.MSG_NoRecordsets);         //alert the user of the problem
    retVal = false;                     //return false to indicate an error
  }
    
  return retVal;
}



//*-------------------------------------------------------------------
// FUNCTION:
//   applyServerBehavior
//
// DESCRIPTION:
//
// ARGUMENTS: 
//
// RETURNS:
//--------------------------------------------------------------------
function RecordsetMenu_applyServerBehavior(sbObj, paramObj) {
  var rsName  = this.listControl.get();
  var rsValue = this.listControl.getValue();
  
  //set the special data source flag, so that the sbManager adds
  // the correct code to the page
  paramObj.MM_dataSource = rsValue;
  
  //add the data source name to the paramObj
  paramObj[this.paramName] = rsName;
  
  return "";
}



//*-------------------------------------------------------------------
// FUNCTION:
//   inspectServerBehavior
//
// DESCRIPTION:
//
// ARGUMENTS: 
//
// RETURNS:
//--------------------------------------------------------------------
function RecordsetMenu_inspectServerBehavior(sbObj, newErrMsgStr) {
  var retVal = false;
  
  var rsName = sbObj.parameters[this.paramName];
  
  //find the name in the list
  for (var i=0; i < this.listControl.getLen() ; i++) {
    if (this.listControl.get(i) == rsName) {
      retVal = this.listControl.setIndex(i);
      break;
    }
  }
  
  //now limit the list to only data sources of the same type
  if (retVal) {
/*    
    var rsValue = this.listControl.getValue(i);
    for (var i=this.listControl.getLen(); i >= 0; i--) {
      if (this.listControl.getValue(i) != rsValue) {
        this.listControl.del(i);
      }
    }
*/    
  } else { // data source name not found
    
    //display error message (default if none). If "" passed in, don't display any error.
    if (newErrMsgStr == null) {
      alert(errMsg(MM.MSG_CouldNotFindRecordsetName,rsName));
    } else if (newErrMsgStr.length) {
      alert(newErrMsgStr);
    }
    
  }
    
  return retVal;
}



//*-------------------------------------------------------------------
// FUNCTION:
//   deleteServerBehavior
//
// DESCRIPTION:
//
// ARGUMENTS: 
//
// RETURNS:
//--------------------------------------------------------------------
function RecordsetMenu_deleteServerBehavior(sbObj) {
  // no op
}



//*-------------------------------------------------------------------
// FUNCTION:
//   analyzeServerBehavior
//
// DESCRIPTION:
//
// ARGUMENTS: 
//
// RETURNS:
//--------------------------------------------------------------------
function RecordsetMenu_analyzeServerBehavior(sbObj, allRecs) {
  if (!sbObj.incomplete && !this.rsNameIsValid(sbObj.parameters[this.paramName])) {
    sbObj.incomplete = true;
  }
}



//*-------------------------------------------------------------------
// FUNCTION:
//   getValue
//
// DESCRIPTION:
//
// ARGUMENTS: 
//
// RETURNS:
//--------------------------------------------------------------------
function RecordsetMenu_getValue() {
  return this.listControl.get();
}



//*-------------------------------------------------------------------
// FUNCTION:
//   findAllRecordsetNames
//
// DESCRIPTION:
//
// ARGUMENTS: 
//
// RETURNS:
//--------------------------------------------------------------------
function RecordsetMenu_findAllRecordsetNames() {
  var nameValueArray = new Array();

  var dsNames = new Array();
  var dsValues = new Array();
  
  //ask dreamweaver for the list of data sources
  var dsList = dw.dbi.getDataSources();
  
  //get the list of groups which reference this server behavior  
  var brList = dw.getExtGroups(this.behaviorName, "serverBehavior");
  
  //for each data source, check if a group file exists for it
  for (var i=0; i < dsList.length; i++) {
    for (var j = 0; j < brList.length; j++) {
      var dsSource = dw.getExtDataValue(brList[j],"dataSource");
      
      if (!dsSource || dsSource == dsList[i].dataSource) {

        //Let make sure we don't have a same data source listed twice because of subtype.
        //until we figure out a solution to support 
        var isExist = false;
        for (var k=0; k < dsNames.length; k++) {
          if (dsList[i].name == dsNames[k]) {
            isExist = true;
          }
        }

        if (!isExist) {
          if (dsList[i].name) {
            dsNames.push(dsList[i].name);
          } else {
            dsNames.push(dsList[i].title);
          }
          dsValues.push(dsList[i].dataSource);
        }
      }
    }
  }
  
  //add the names and values arrays to the return array
  nameValueArray.push(dsNames);
  nameValueArray.push(dsValues);

  return nameValueArray;
}



//*-------------------------------------------------------------------
// FUNCTION:
//   rsNameIsValid
//
// DESCRIPTION:
//
// ARGUMENTS: 
//
// RETURNS:
//--------------------------------------------------------------------
function RecordsetMenu_rsNameIsValid(rsName) {
  var retVal = false;
  
  if (MM.findAllRecordsetNames != null) {  //if cache exists, use that
    var nameValueArray = MM.findAllRecordsetNames;
  } else {
    var nameValueArray = this.findAllRecordsetNames();
  }
  
  var rsNames    = nameValueArray[0];

  for (var i=0; i < rsNames.length; i++) {
    if (rsNames[i] == rsName) {
      retVal = true;
      break;
    }
  }
  
  return retVal;
}

